@@ -210,6 +210,7 @@ static void closeServer(sock)
 {
 	msqlDebug(MOD_API,"Server socket (%d) closed\n", sock);
 	shutdown(sock,2);
+	signal(SIGPIPE,oldHandler);
 	close(sock);
 }
 
@@ -255,7 +256,6 @@ RETSIGTYPE pipeHandler(sig)
 {
 	msqlDebug(MOD_API,"Hit by pipe signal\n");
 	closeServer(curServerSock);
-	signal(SIGPIPE,pipeHandler);
 	return;
 }
 
@@ -455,14 +455,14 @@ int msqlConnect(host)
 	}
 	else
 	{
-	        tcpPort = MSQL_PORT;
+	        tcpPort = ntohs(MSQL_PORT);
         	if ((serv_ptr = getservbyname("msql", "tcp")))
         	{
-                	tcpPort = serv_ptr->s_port;
+                	tcpPort = ntohs(serv_ptr->s_port);
         	}
         	if ((envVar = getenv("MSQL_TCP_PORT")))
         	{
-                	tcpPort = atoi(envVar);
+                	tcpPort = ntohs(atoi(envVar));
         	}
 
 		sprintf(hostInfo,"%s via TCP/IP",host);
@@ -1020,12 +1020,12 @@ int readQueryData(sock)
 			cp = (char *)index(cp,':');
 			if (len == -2)
 			{
-				cur->data[off] = (u_char *)NULL;
+				cur->data[off] = (char *)NULL;
 				cp++;
 			}
 			else
 			{
-				cur->data[off] = (u_char *)malloc(len+1);
+				cur->data[off] = (char *)malloc(len+1);
 				(void)bzero(cur->data[off],len+1);
 				(void)bcopy(cp+1,cur->data[off],len);
 				cp += len + 1;
