@@ -32,7 +32,7 @@
 #define MAX_FIELDS	75		/* Max fields per query */
 #define MAX_CON		24		/* Max connections */
 #define BUF_SIZE	(256*1024)	/* Read buf size if no mmap() */
-#define NAME_LEN	20		/* Field/table name length */
+#define NAME_LEN	19		/* Field/table name length */
 #define	PKT_LEN		(32*1024)	/* Max size of client/server packet */
 #define	CACHE_SIZE	8		/* Size of table cache */
 
@@ -49,8 +49,8 @@
 ** Identifier format.  Multi-part to enable stuff like "emp.name"
 */
 typedef struct ident_s {
-	char	seg1[NAME_LEN],
-		seg2[NAME_LEN];
+	char	seg1[NAME_LEN + 2],
+		seg2[NAME_LEN + 2];
 } ident_t;
 
 
@@ -71,8 +71,8 @@ typedef struct val_s {
 
 
 typedef struct tname_s {
-	char	name[NAME_LEN + 1],
-		cname[NAME_LEN + 1];
+	char	name[NAME_LEN + 2],
+		cname[NAME_LEN + 2];
 	struct	tname_s *next;
 } tname_t;
 
@@ -80,8 +80,8 @@ typedef struct tname_s {
 ** Internal field list element
 */
 typedef struct field_ps {		
-	char	table[NAME_LEN],
-		name[NAME_LEN];
+	char	table[NAME_LEN + 1],
+		name[NAME_LEN + 1];
 	val_t 	*value;
 	int	type,
 		length,
@@ -96,8 +96,8 @@ typedef struct field_ps {
 ** Where clause list element 
 */
 typedef struct cond_s {			
-	char	table[NAME_LEN + 1],
-		name[NAME_LEN + 1];
+	char	table[NAME_LEN + 2],
+		name[NAME_LEN + 2];
 	val_t 	*value;
 	int	op,
 		bool,
@@ -109,7 +109,7 @@ typedef struct cond_s {
 
 
 typedef struct tlist_s {
-	char	name[NAME_LEN + 1];
+	char	name[NAME_LEN + 2];
 	struct	tlist_s *next;
 } tlist_t;
 
@@ -118,8 +118,8 @@ typedef struct tlist_s {
 ** Order clause list element 
 */
 typedef struct order_s {		
-	char	table[NAME_LEN + 1],
-		name[NAME_LEN + 1];
+	char	table[NAME_LEN + 2],
+		name[NAME_LEN + 2];
 	int	dir,
 		type,
 		length;
@@ -133,10 +133,10 @@ typedef struct order_s {
 ** Table cache entry struct 
 */
 typedef struct cache_s {		
-	char	DB[NAME_LEN + 1],
-		cname[NAME_LEN + 1],
-		table[NAME_LEN + 1],
-		resInfo[4 * NAME_LEN]; /* used for debugging info */
+	char	DB[NAME_LEN + 2],
+		cname[NAME_LEN + 2],
+		table[NAME_LEN + 2],
+		resInfo[4 * (NAME_LEN+1)]; /* used for debugging info */
 	u_char	*rowBuf,
 		*keyBuf;
 	int	age,
@@ -298,7 +298,7 @@ static char *blockTags[] = {
 
 
 
-void writePkt();
+int writePkt();
 int readPkt();
 
 
